﻿#Общая документация тут: https://cloud.google.com/text-to-speech/

#Путь к файлу json-ключа сервисного аккаунта (https://cloud.google.com/text-to-speech/docs/before-you-begin#creating_a_json_key_for_your_service_account):
$env:GOOGLE_APPLICATION_CREDENTIALS = "d:\GoogleTTS\srv-tts.json"

#Каталог для генерируемых файлов json и wav
$OutputFolderPath = "d:\GoogleTTS\Sounds"

#Список фраз для озвучки, имя файла пишем без расширения
#имя файла:фраза на русском
$Strings = @'
fm01:Режим взлёта
fm02:Режим полёта
fm03:Режим посадки
'@ -split "`r`n"

#Шаблон Json
#Параметры аудио здесь: https://cloud.google.com/text-to-speech/docs/reference/rest/v1/text/synthesize#audioencoding
$json = @{
    audioConfig = @{
        audioEncoding = "LINEAR16"
        pitch = 0
        speakingRate = 1
        sampleRateHertz =32000
        volumeGainDb ="+10"
    }
    voice = @{
        languageCode = "ru-RU"
        name = "ru-RU-Wavenet-E"
    }
    input = @{
        text = "Текст"
    }
}

$files = @()

#В цикле формируем json-файлы в папке $OutputFolderPath:
foreach ($phrase in $Strings) {
    $parts = $phrase.Split(':',2)
    $json.input.text = $parts[1].Trim()
    $str = $json | ConvertTo-Json -Compress
    $fileName = $OutputFolderPath + "\" + $parts[0] + ".json" 
    [System.IO.File]::WriteAllText($fileName, $str, [System.Text.Encoding]::UTF8)
    Write-Host $fileName -ForegroundColor Yellow #имя файла JSON
    $files += @($fileName)
}

$cred = gcloud auth application-default print-access-token

$headers = @{ "Authorization" = "Bearer $cred" }

$response = @()

#В цикле выполняем запросы к Google Cloud Text-to-Speech, полученные json-ответы конвертируем в wav-файлы
foreach ($file in $files) {
    Write-Host "File and data: $file , data: $([System.IO.File]::ReadAllText($file))"
    $response = Invoke-WebRequest -UseBasicParsing -DisableKeepAlive `
      -Method POST `
      -Headers $headers `
      -ContentType: "application/json; charset=utf-8" `
      -InFile $file `
      -Uri "https://texttospeech.googleapis.com/v1/text:synthesize"
    
    $json = $response.Content | ConvertFrom-Json 
    $bytes = [System.Convert]::FromBase64String($json.audioContent)
    $outputFile = [System.IO.Path]::ChangeExtension($file, '.wav')
    [System.IO.File]::WriteAllBytes($outputFile, $bytes)
    Write-Host $outputFile -ForegroundColor Green
}